// noinspection JSJQueryEfficiency

/**
 * @file
 * Js for Glossary Content.
 */

(($, Drupal, once) => {
  Drupal.behaviors.GlossaryContent = {
    attach(context) {
      const tLoading = Drupal.t('Loading...');
      if (context === document) {
        // Allow dialog title translation.
        const tTermDefinition = Drupal.t('Term definition');
        $('body').append(
          `<div id="glossary-dialog" class="hidden" title="${tTermDefinition}"><div id="glossary-dialog-inner"><div class="ajax-progress ajax-progress-throbber"><div class="ajax-throbber">${tLoading}</div></div></div></div>`,
        );
      }
      const $dialog = $(once('glossary-dialog', '#glossary-dialog'));
      $(once('glossaryListener', '.glos-term')).on(
        // WCAG: handle keypress event.
        'click keypress',
        function onTermActivation(event) {
          event.preventDefault();
          const termId = $(this).data('gterm');
          const termText = this.textContent;
          const dialog = $dialog.dialog({
            autoOpen: true,
            resizable: false,
            modal: true,
            // Allow default close label translation.
            closeText: Drupal.t('Close'),
            close() {
              $(this)
                .find('#glossary-dialog-inner')
                .html(
                  `<div class="ajax-progress ajax-progress-throbber"><div class="ajax-throbber">${tLoading}</div></div>`,
                );
            },
            buttons: [
              {
                // Allow close button label translation.
                text: Drupal.t('Close'),
                click(evt) {
                  evt.preventDefault();
                  dialog.dialog('close');
                },
                // WCAG: handle keypress event.
                keypress(evt) {
                  // Needed to avoid the click event being fired next.
                  evt.preventDefault();
                  dialog.dialog('close');
                },
              },
            ],
          });
          // Call Ajax here.
          const url = Drupal.url(`glossary-get-term-by-id/${termId}`);
          $.ajax({
            url,
            dataType: 'json',
            type: 'GET',
            success(data) {
              const $dialogInner = $dialog.find('#glossary-dialog-inner');
              $dialogInner.html('');
              if (data.name && data.description) {
                $dialogInner.append(`<p><strong>${data.name}</strong></p>`);
                $dialogInner.append(data.description);
                $dialogInner.removeClass('hidden');
                const showEvent = new CustomEvent('glossary_modal_show', {
                  detail: data,
                });
                document.dispatchEvent(showEvent);
              } else {
                // Allow "no results" message translation.
                const tNoResultsFound = Drupal.t('No results found for @term', {
                  '@term': termText,
                });
                $dialogInner.html(tNoResultsFound);
              }
            },
          });
        },
      );
    },
  };
})(jQuery, Drupal, once);
